@@ -3,6 +3,10 @@ import logging
 import os
 from typing import Optional
 
+from dls_servbase_lib.configurators.configurators import (
+    dls_servbase_configurators_set_default,
+)
+
 # Utilities.
 from dls_utilpack.callsign import callsign
 from dls_utilpack.require import require
@@ -26,6 +30,9 @@ def configurators_set_default(configurator):
     global __default_configurator
     __default_configurator = configurator
 
+    # We share configurator with servbase.
+    dls_servbase_configurators_set_default(configurator)
+
 
 def configurators_get_default():
     global __default_configurator
